<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use App\Http\Requests\Auth\ResetPasswordRequest;
use App\Http\Requests\Auth\SetNewPasswordRequest;
use App\Services\Mail\MailService;
use App\Services\User\UserService;
use App\Services\Verification\VerificationService;
use Exception;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;

class ResetPasswordController extends Controller
{
    /**
     * @var UserService
     */
    protected UserService $userService;
    /**
     * @var VerificationService
     */
    protected VerificationService $verificationService;
    /**
     * @var MailService
     */
    protected MailService $mailService;

    /**
     * @param UserService $userService
     * @param VerificationService $verificationService
     * @param MailService $mailService
     */
    public function __construct(UserService $userService, VerificationService $verificationService, MailService $mailService)
    {
        $this->userService = $userService;
        $this->verificationService = $verificationService;
        $this->mailService = $mailService;
    }

    /**
     * @param ResetPasswordRequest $request
     * @return JsonResponse
     * @throws Exception
     */
    public function sendEmailToResetPassword(ResetPasswordRequest $request): JsonResponse
    {
        $email = $request->validated()['email'];
        $user = $this->userService->getUserByEmail($email);
        $verificationUrl = $this->verificationService->generateVerificationUrl($email, 'resetPassword.verify');
        $this->mailService->sendVerificationMail("RestPassword", $verificationUrl, $user, 'rest password ');
        return success(msg: 'we sent verification code to your email  ');
    }

    /**
     * @param Request $request
     * @return string
     */
    public function verifiedResetPassword(Request $request): string
    {
        $email = decrypt($request->email);
        $token = $this->verificationService->confirmVerificationLink($email);
        return ' here i need to return link form the front end and the link must contain token ' . $token;
    }

    /**
     * @param SetNewPasswordRequest $request
     * @return JsonResponse
     */
    public function setNewPassword(SetNewPasswordRequest $request): JsonResponse
    {
        $newPassword = $request->validated()['password'];
        $user = $request->user();
        $this->userService->restPassword($user, $newPassword);
        return success(msg: 'password has been changed');
    }
}
