<?php

namespace App\Mail;

use App\Models\User;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Mail\Mailable;
use Illuminate\Mail\Mailables\Attachment;
use Illuminate\Mail\Mailables\Content;
use Illuminate\Mail\Mailables\Envelope;
use Illuminate\Queue\SerializesModels;

class SendVerificationCodeMail extends Mailable implements ShouldQueue
{

    use Queueable, SerializesModels;

    /**
     * @var User
     */
    public User $user;
    /**
     * @var string
     */
    public string $verificationUrl;
    /**
     * @var string
     */
    public string $mailSubject;
    /**
     * @var string|null
     */
    public ?string $verificationCode;
    /**
     * @var string
     */
    private string $linkFor;

    /**
     * Create a new message instance.
     *
     * @param User $user
     * @param string $mailSubject
     * @param string $verificationUrl
     * @param string $linkFor
     * @param string|null $verificationCode
     */
    public function __construct(User $user,string $mailSubject  , string $verificationUrl, string $linkFor, ?string $verificationCode = null )
    {
        $this->user = $user;
        $this->verificationUrl = $verificationUrl;
        $this->verificationCode = $verificationCode;
        $this->linkFor = $linkFor;
        $this->mailSubject = $mailSubject;
    }


    /**
     * Get the message envelope.
     */
    public function envelope(): Envelope
    {
        return new Envelope(
            from: config('mail.from.address'),
            subject: $this->mailSubject
        );
    }

    /**
     * Get the message content definition.
     */
    public function content(): Content
    {
        return new Content(
            view: 'Email.emailVerificationTemplate',
            with: [
                'userName' => $this->user->first_name,
                'userEmail' => $this->user->email,
                'verificationCode' => $this->verificationCode,
                'urlVerification' => $this->verificationUrl,
                'theButtonText' => $this->linkFor,
            ]
        );
    }

    /**
     * Get the attachments for the message.
     *
     * @return array<int, Attachment>
     */
    public function attachments(): array
    {
        return [];
    }
}
