<?php

namespace App\Services\Auth;

use App\Models\User;
use App\Services\User\UserService;
use App\Services\Verification\VerificationService;
use Exception;
use Illuminate\Support\Facades\Hash;
use Illuminate\Validation\ValidationException;
use RuntimeException;

class AuthService
{
    protected UserService $userService;
    protected VerificationService $verificationService;

    /**
     * inject the services when the instance created
     *
     * @param UserService $userService
     * @param VerificationService $verificationService
     */
    public function __construct(UserService $userService, VerificationService $verificationService)
    {
        $this->userService = $userService;
        $this->verificationService = $verificationService;
    }

    /**
     * Register a new user.
     *
     * @param array $data
     * @throws Exception
     */
    public function register(array $data): void
    {

        if (!$user = $this->userService->createUser($data))
            throw  new Exception('the register operation is not working , pleas try again ');
        $this->verificationService->sendVerificationCodeViaEmail($user);
    }

    /**
     * @throws ValidationException
     */
    public function login($data)
    {
        $user =$this->userService->getUserByEmail($data['email']);
        $this->validateUserCredentials($data ,$user);
        if(!$this->userService->userIsVerified($user)){
            Throw new RuntimeException('your email is not verified, please verify your email ');
        }
        return $this->createToken($user);
    }


    public function createToken(User $user): string
    {
        return $user->createToken('auth_token', ['*'], now()->addDays(config('sanctum.custom-expiration')[0]))->plainTextToken;
    }

    /**
     * @throws ValidationException
     */
    public function validateUserCredentials($data , User $user): void
    {
        if (!Hash::check($data['password'], $user->password)) {
            throw ValidationException::withMessages([
                'email' => ['The provided credentials are incorrect.'],
            ]);
        }
    }





}
