<?php

namespace App\Services\Else;

use Exception;

class RandomStringGeneratorService
{
    private string $upperCaseLetters = 'ABCDEFGHIJKLMNOPQRSTUVWXYZ';
    private string $lowerCaseLetters = 'abcdefghijklmnopqrstuvwxyz';
    private string $numbers = '0123456789';

    /**
     * Generate a random string with the given length, ensuring it contains
     * at least one uppercase letter, one lowercase letter, and one number.
     *
     * @param int $length
     * @return string
     * @throws Exception
     */
    public function generate(int $length = 6): string
    {
        if ($length < 3) {
            throw new \InvalidArgumentException('Length must be at least 3 to include all required character types.');
        }

        $randomString = $this->getRandomCharacter($this->upperCaseLetters)
            . $this->getRandomCharacter($this->lowerCaseLetters)
            . $this->getRandomCharacter($this->numbers);

        $remainingLength = $length - 3;
        $randomString .= $this->getRandomCharacters($remainingLength);

        return str_shuffle($randomString);
    }

    /**
     * Get a random character from a given string.
     *
     * @param string $characters
     * @return string
     * @throws Exception
     */
    private function getRandomCharacter(string $characters): string
    {
        return $characters[random_int(0, strlen($characters) - 1)];
    }

    /**
     * Get a string of random characters of a specified length.
     *
     * @param int $length
     * @return string
     * @throws Exception
     */
    private function getRandomCharacters(int $length): string
    {
        $allCharacters = $this->upperCaseLetters . $this->lowerCaseLetters . $this->numbers;
        $randomCharacters = '';

        for ($i = 0; $i < $length; $i++) {
            $randomCharacters .= $this->getRandomCharacter($allCharacters);
        }

        return $randomCharacters;
    }
}
