<?php

namespace App\Services\User;

use App\Models\User;
use Illuminate\Database\Eloquent\ModelNotFoundException;
use Symfony\Component\HttpKernel\Exception\BadRequestHttpException;

class UserService
{
    /**
     * @param array $data
     * @return User
     */
    public function createUser(array $data): User
    {
        // Create the user with the prepared data
        return User::create($data);
    }

    public function getUserByEmail($email): User
    {
        if (!$user = User::where('email', $email)->first())
            throw  new ModelNotFoundException('there is no user with this email');
        return $user;
    }

    public function throwIfUserVerified(User $user): void
    {
        if ($user->email_verified_at)
            throw  new BadRequestHttpException('user already verified');
    }

    public function userIsVerified(User $user): bool
    {
        return (bool) $user->email_verified_at;
    }



    public function checkUserByEmail($email, &$user): bool
    {
        $user = User::where('email', $email)->first();
        return $user !== null;
    }

    public function createUserFromGoogle($googleUser)
    {
                $user =User::create([
                'first_name' => $googleUser->getName(),
                'email' => $googleUser->getEmail(),
                'google_id' => $googleUser->getId(),
                'auth_type' => 'google',
                'password' => bcrypt('default-password')
                ]);
                if(!$user){
                    throw new BadRequestHttpException('create user failed , please try again');
                }
                return $user;
    }


    public function restPassword(User $user, string $newPassword)
    {
        $user->setPasswordAttribute($newPassword);
    }

}
