<?php


use Illuminate\Database\Eloquent\ModelNotFoundException;
use Symfony\Component\Finder\Exception\AccessDeniedException;
use Illuminate\Auth\{
    Access\AuthorizationException,
    AuthenticationException
};
use Illuminate\Validation\{
    UnauthorizedException,
    ValidationException
};
use Symfony\Component\HttpKernel\Exception\{
    BadRequestHttpException,
    ConflictHttpException ,
    NotFoundHttpException,
    UnprocessableEntityHttpException
};


return [

    /*
    |--------------------------------------------------------------------------
    | Exception Handling Mappings
    |--------------------------------------------------------------------------
    |
    | Here you may define how your application handles various exceptions.
    | Each exception type can be mapped to a specific method for processing.
    | This allows you to centralize your exception handling logic, making
    | your code more maintainable and easier to understand.
    |
    */

    // Handle cases where a model is not found in the database
    ModelNotFoundException::class => 'handleModelNotFoundException',

    // Handle cases where a route or resource is not found
    NotFoundHttpException::class => 'handleNotFoundHttpException',

    // Handle cases where the request data is unprocessable
    UnprocessableEntityHttpException::class => 'handleUnprocessableEntityException',

    // Handle authentication failures
    AuthenticationException::class => 'handleAuthenticationException',

    // Handle authorization failures
    AuthorizationException::class => 'handleAuthorizationException',

    // Handle bad request exceptions
    BadRequestHttpException::class => 'handleBadRequestException',

    // Handle cases where there is a conflict in the request data
    ConflictHttpException::class => 'handleConflictHttpException',

    // Handle validation errors
    ValidationException::class => 'handleValidationException',

    // Handle unauthorized access attempts
    UnauthorizedException::class => 'handleUnauthorizedException',

    // Handle access denied exceptions
    AccessDeniedException::class => 'handleAccessDeniedException',

];
